dgr_graph, get node
attribute properties for nodes available in a selection and deposit
those values in the graph for later retrieval using withdraw_values.
deposit_node_attr_from_selection(graph, node_attr, mode = NULL)dgr_graph that is created
using create_graph.numeric or character.dgr_graph.