dgr_graph, query an edge in the graph (defined by a pair of node IDs extant in the graph) and perform operations on the relationship for that edge.edge_relationship(graph, from, to, action = "read", value = NULL)dgr_graph that is created using create_graph.delete, remove, or drop. To add a relationship to an edge with no set relationship, use adddgr_graph.