get_cmty_fast_greedy: Get community membership by modularity optimization

View source: R/get_cmty_fast_greedy.R

get_cmty_fast_greedyR Documentation

Get community membership by modularity optimization

Description

Through the use of greedy optimization of a modularity score, obtain the group membership values for each of the nodes in the graph. Note that this method only works on graphs without multiple edges.

Usage

get_cmty_fast_greedy(graph)

Arguments

graph

A graph object of class dgr_graph.

Value

a data frame with group membership assignments for each of the nodes.

Examples

# Create a graph with a
# balanced tree
graph <-
  create_graph() |>
  add_balanced_tree(
    k = 2,
    h = 2)

# Get the group membership
# values for all nodes in
# the graph through the greedy
# optimization of modularity
# algorithm
graph |>
  get_cmty_fast_greedy()

# Add the group membership
# values to the graph as a
# node attribute
graph <-
  graph |>
  join_node_attrs(
    df = get_cmty_fast_greedy(graph))

# Display the graph's
# node data frame
graph |> get_node_df()


DiagrammeR documentation built on April 27, 2026, 5:06 p.m.