get_cmty_louvain: Get community membership by Louvain optimization

View source: R/get_cmty_louvain.R

get_cmty_louvainR Documentation

Get community membership by Louvain optimization

Description

Through the use of multi-level optimization of a modularity score, obtain the group membership values for each of the nodes in the graph.

Usage

get_cmty_louvain(graph)

Arguments

graph

A graph object of class dgr_graph.

Value

A data frame with group membership assignments for each of the nodes.

Examples

# Create a random graph using the
# `add_gnm_graph()` function
graph <-
  create_graph(
    directed = FALSE) |>
  add_gnm_graph(
    n = 10,
    m = 15,
    set_seed = 23)

# Get the group membership values
# for all nodes in the graph
# through the multi-level
# optimization of modularity
# algorithm
graph |>
  get_cmty_louvain()

# Add the group membership
# values to the graph as a
# node attribute
graph <-
  graph |>
  join_node_attrs(
    df = get_cmty_louvain(graph))

# Display the graph's
# node data frame
graph |> get_node_df()


DiagrammeR documentation built on April 27, 2026, 5:06 p.m.