get_edge_info: Get detailed information on edges

View source: R/get_edge_info.R

get_edge_infoR Documentation

Get detailed information on edges

Description

Obtain a data frame with detailed information on edges and their interrelationships within the graph.

Usage

get_edge_info(graph)

Arguments

graph

A graph object of class dgr_graph.

Value

A data frame containing information specific to each edge within the graph.

Examples

# Create a simple graph
graph <-
  create_graph() |>
  add_gnm_graph(
    n = 5, m = 10,
    set_seed = 23)

# Get information on the
# graph's edges
graph |> get_edge_info()


DiagrammeR documentation built on April 27, 2026, 5:06 p.m.