get_w_connected_cmpts: Get all nodes associated with connected components

View source: R/get_w_connected_cmpts.R

get_w_connected_cmptsR Documentation

Get all nodes associated with connected components

Description

Determine which nodes in a graph belong to different weakly connected components (i.e., distinct sets of nodes with traversable paths to and from each node in the set).

Usage

get_w_connected_cmpts(graph)

Arguments

graph

A graph object of class dgr_graph.

Value

A data frame with nodes and their membership in different weakly connected components.

Examples

# Create a graph with 2 cycles
graph <-
  create_graph() |>
  add_cycle(n = 4) |>
  add_cycle(n = 3)

# Check if the graph is connected
graph |>
  is_graph_connected()

# Get the graph's weakly-connected
# components
graph |> get_w_connected_cmpts()


DiagrammeR documentation built on April 27, 2026, 5:06 p.m.