View source: R/select_last_edges_created.R
| select_last_edges_created | R Documentation |
Select the last edges that were created in a graph object of class
dgr_graph. This function should ideally be used just after creating the
edges to be selected.
select_last_edges_created(graph)
graph |
A graph object of class |
A graph object of class dgr_graph.
# Create a graph and add a cycle and then
# a tree in 2 separate function calls
graph <-
create_graph() |>
add_cycle(
n = 3,
rel = "a") |>
add_balanced_tree(
k = 2, h = 2,
rel = "b")
# Select the last edges created (all edges
# from the tree) and then set their edge
# color to be `red`
graph <-
graph |>
select_last_edges_created() |>
set_edge_attrs_ws(
edge_attr = color,
value = "red") |>
clear_selection()
# Display the graph's internal edge
# data frame to verify the change
graph |> get_edge_df()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.