dgr_graph move toward both
predecessor and successor nodes from one or more nodes present in a
selection. The current nodes in the selection are replaced with those nodes
traversed to.
trav_both(graph, node_attr = NULL, match = NULL)dgr_graph that is created
using create_graph.>, <, ==, or !=) followed by a number
for numerical filtering, or, a character string for filtering the edges
returned through string matching.dgr_graph.