dgr_graph move outward
from one or more nodes present in a selection to other nodes, replacing
the current nodes in the selection with those nodes traversed to.
trav_out(graph, node_attr = NULL, match = NULL)dgr_graph that is created
using create_graph.>, <, ==, or !=) followed by a number
for numerical filtering, or, a character string for filtering the edges
returned through string matching.dgr_graph.